# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class OutputModelPrecisionOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'time': 'datetime',
        'step_value': 'float',
        'precision_diff_value': 'float',
        'node_code': 'str'
    }

    attribute_map = {
        'id': 'id',
        'time': 'time',
        'step_value': 'stepValue',
        'precision_diff_value': 'precisionDiffValue',
        'node_code': 'nodeCode'
    }

    def __init__(self, id=None, time=None, step_value=None, precision_diff_value=None, node_code=None, local_vars_configuration=None):  # noqa: E501
        """OutputModelPrecisionOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._time = None
        self._step_value = None
        self._precision_diff_value = None
        self._node_code = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if time is not None:
            self.time = time
        if step_value is not None:
            self.step_value = step_value
        if precision_diff_value is not None:
            self.precision_diff_value = precision_diff_value
        self.node_code = node_code

    @property
    def id(self):
        """Gets the id of this OutputModelPrecisionOutput.  # noqa: E501


        :return: The id of this OutputModelPrecisionOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OutputModelPrecisionOutput.


        :param id: The id of this OutputModelPrecisionOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def time(self):
        """Gets the time of this OutputModelPrecisionOutput.  # noqa: E501

        时间 time  # noqa: E501

        :return: The time of this OutputModelPrecisionOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this OutputModelPrecisionOutput.

        时间 time  # noqa: E501

        :param time: The time of this OutputModelPrecisionOutput.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def step_value(self):
        """Gets the step_value of this OutputModelPrecisionOutput.  # noqa: E501

        精度百分比 precision ratio (onlineValue - modelResultValue / onlineValue)  # noqa: E501

        :return: The step_value of this OutputModelPrecisionOutput.  # noqa: E501
        :rtype: float
        """
        return self._step_value

    @step_value.setter
    def step_value(self, step_value):
        """Sets the step_value of this OutputModelPrecisionOutput.

        精度百分比 precision ratio (onlineValue - modelResultValue / onlineValue)  # noqa: E501

        :param step_value: The step_value of this OutputModelPrecisionOutput.  # noqa: E501
        :type: float
        """

        self._step_value = step_value

    @property
    def precision_diff_value(self):
        """Gets the precision_diff_value of this OutputModelPrecisionOutput.  # noqa: E501

        精度差值 precision difference (onlineValue - modelResultValue)  # noqa: E501

        :return: The precision_diff_value of this OutputModelPrecisionOutput.  # noqa: E501
        :rtype: float
        """
        return self._precision_diff_value

    @precision_diff_value.setter
    def precision_diff_value(self, precision_diff_value):
        """Sets the precision_diff_value of this OutputModelPrecisionOutput.

        精度差值 precision difference (onlineValue - modelResultValue)  # noqa: E501

        :param precision_diff_value: The precision_diff_value of this OutputModelPrecisionOutput.  # noqa: E501
        :type: float
        """

        self._precision_diff_value = precision_diff_value

    @property
    def node_code(self):
        """Gets the node_code of this OutputModelPrecisionOutput.  # noqa: E501

        模型节点 model node  # noqa: E501

        :return: The node_code of this OutputModelPrecisionOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_code

    @node_code.setter
    def node_code(self, node_code):
        """Sets the node_code of this OutputModelPrecisionOutput.

        模型节点 model node  # noqa: E501

        :param node_code: The node_code of this OutputModelPrecisionOutput.  # noqa: E501
        :type: str
        """

        self._node_code = node_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OutputModelPrecisionOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OutputModelPrecisionOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultRiverWQsOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time': 'list[str]',
        'i_ds': 'list[str]',
        'wq_item': 'str',
        'concentration': 'list[list[float]]'
    }

    attribute_map = {
        'time': 'time',
        'i_ds': 'iDs',
        'wq_item': 'wqItem',
        'concentration': 'concentration'
    }

    def __init__(self, time=None, i_ds=None, wq_item=None, concentration=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultRiverWQsOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time = None
        self._i_ds = None
        self._wq_item = None
        self._concentration = None
        self.discriminator = None

        self.time = time
        self.i_ds = i_ds
        self.wq_item = wq_item
        self.concentration = concentration

    @property
    def time(self):
        """Gets the time of this ModelResultRiverWQsOutput.  # noqa: E501

        时间 time  # noqa: E501

        :return: The time of this ModelResultRiverWQsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ModelResultRiverWQsOutput.

        时间 time  # noqa: E501

        :param time: The time of this ModelResultRiverWQsOutput.  # noqa: E501
        :type: list[str]
        """

        self._time = time

    @property
    def i_ds(self):
        """Gets the i_ds of this ModelResultRiverWQsOutput.  # noqa: E501

        河道名,里程 river,chainage  # noqa: E501

        :return: The i_ds of this ModelResultRiverWQsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._i_ds

    @i_ds.setter
    def i_ds(self, i_ds):
        """Sets the i_ds of this ModelResultRiverWQsOutput.

        河道名,里程 river,chainage  # noqa: E501

        :param i_ds: The i_ds of this ModelResultRiverWQsOutput.  # noqa: E501
        :type: list[str]
        """

        self._i_ds = i_ds

    @property
    def wq_item(self):
        """Gets the wq_item of this ModelResultRiverWQsOutput.  # noqa: E501

        水质 water quality item  # noqa: E501

        :return: The wq_item of this ModelResultRiverWQsOutput.  # noqa: E501
        :rtype: str
        """
        return self._wq_item

    @wq_item.setter
    def wq_item(self, wq_item):
        """Sets the wq_item of this ModelResultRiverWQsOutput.

        水质 water quality item  # noqa: E501

        :param wq_item: The wq_item of this ModelResultRiverWQsOutput.  # noqa: E501
        :type: str
        """

        self._wq_item = wq_item

    @property
    def concentration(self):
        """Gets the concentration of this ModelResultRiverWQsOutput.  # noqa: E501

        浓度 concentration  # noqa: E501

        :return: The concentration of this ModelResultRiverWQsOutput.  # noqa: E501
        :rtype: list[list[float]]
        """
        return self._concentration

    @concentration.setter
    def concentration(self, concentration):
        """Sets the concentration of this ModelResultRiverWQsOutput.

        浓度 concentration  # noqa: E501

        :param concentration: The concentration of this ModelResultRiverWQsOutput.  # noqa: E501
        :type: list[list[float]]
        """

        self._concentration = concentration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultRiverWQsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultRiverWQsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class SaveHistorySearchRecordInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'is_default': 'bool',
        'indicator': 'str',
        'is_search_simul': 'bool',
        'is_search_online': 'bool',
        'scene': 'str'
    }

    attribute_map = {
        'name': 'name',
        'is_default': 'isDefault',
        'indicator': 'indicator',
        'is_search_simul': 'isSearchSimul',
        'is_search_online': 'isSearchOnline',
        'scene': 'scene'
    }

    def __init__(self, name=None, is_default=None, indicator=None, is_search_simul=None, is_search_online=None, scene=None, local_vars_configuration=None):  # noqa: E501
        """SaveHistorySearchRecordInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._is_default = None
        self._indicator = None
        self._is_search_simul = None
        self._is_search_online = None
        self._scene = None
        self.discriminator = None

        self.name = name
        if is_default is not None:
            self.is_default = is_default
        self.indicator = indicator
        if is_search_simul is not None:
            self.is_search_simul = is_search_simul
        if is_search_online is not None:
            self.is_search_online = is_search_online
        self.scene = scene

    @property
    def name(self):
        """Gets the name of this SaveHistorySearchRecordInput.  # noqa: E501

        历史搜索条件记录  # noqa: E501

        :return: The name of this SaveHistorySearchRecordInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SaveHistorySearchRecordInput.

        历史搜索条件记录  # noqa: E501

        :param name: The name of this SaveHistorySearchRecordInput.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def is_default(self):
        """Gets the is_default of this SaveHistorySearchRecordInput.  # noqa: E501

        是否是默认展示点位  # noqa: E501

        :return: The is_default of this SaveHistorySearchRecordInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this SaveHistorySearchRecordInput.

        是否是默认展示点位  # noqa: E501

        :param is_default: The is_default of this SaveHistorySearchRecordInput.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def indicator(self):
        """Gets the indicator of this SaveHistorySearchRecordInput.  # noqa: E501

        指标编码  # noqa: E501

        :return: The indicator of this SaveHistorySearchRecordInput.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this SaveHistorySearchRecordInput.

        指标编码  # noqa: E501

        :param indicator: The indicator of this SaveHistorySearchRecordInput.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def is_search_simul(self):
        """Gets the is_search_simul of this SaveHistorySearchRecordInput.  # noqa: E501

        是否需要查询模拟数据  # noqa: E501

        :return: The is_search_simul of this SaveHistorySearchRecordInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_search_simul

    @is_search_simul.setter
    def is_search_simul(self, is_search_simul):
        """Sets the is_search_simul of this SaveHistorySearchRecordInput.

        是否需要查询模拟数据  # noqa: E501

        :param is_search_simul: The is_search_simul of this SaveHistorySearchRecordInput.  # noqa: E501
        :type: bool
        """

        self._is_search_simul = is_search_simul

    @property
    def is_search_online(self):
        """Gets the is_search_online of this SaveHistorySearchRecordInput.  # noqa: E501

        是否需要查询在线数据  # noqa: E501

        :return: The is_search_online of this SaveHistorySearchRecordInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_search_online

    @is_search_online.setter
    def is_search_online(self, is_search_online):
        """Sets the is_search_online of this SaveHistorySearchRecordInput.

        是否需要查询在线数据  # noqa: E501

        :param is_search_online: The is_search_online of this SaveHistorySearchRecordInput.  # noqa: E501
        :type: bool
        """

        self._is_search_online = is_search_online

    @property
    def scene(self):
        """Gets the scene of this SaveHistorySearchRecordInput.  # noqa: E501

        搜索条件应用场景  # noqa: E501

        :return: The scene of this SaveHistorySearchRecordInput.  # noqa: E501
        :rtype: str
        """
        return self._scene

    @scene.setter
    def scene(self, scene):
        """Sets the scene of this SaveHistorySearchRecordInput.

        搜索条件应用场景  # noqa: E501

        :param scene: The scene of this SaveHistorySearchRecordInput.  # noqa: E501
        :type: str
        """

        self._scene = scene

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveHistorySearchRecordInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveHistorySearchRecordInput):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_message_service.api.message_type_api import MessageTypeApi
from dhicn_message_service.api.message_type_temp_local_api import MessageTypeTempLocalApi
from dhicn_message_service.api.task_schedule_api import TaskScheduleApi
from dhicn_message_service.api.uni_push_api import UniPushApi
from dhicn_message_service.api.user_client_api import UserClientApi
from dhicn_message_service.api.user_message_center_api import UserMessageCenterApi



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class DosageBasicInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'production_line': 'str',
        'is_intelligence': 'bool',
        'code': 'str',
        'dosage': 'float',
        'category': 'int'
    }

    attribute_map = {
        'production_line': 'productionLine',
        'is_intelligence': 'isIntelligence',
        'code': 'code',
        'dosage': 'dosage',
        'category': 'category'
    }

    def __init__(self, production_line=None, is_intelligence=None, code=None, dosage=None, category=None, local_vars_configuration=None):  # noqa: E501
        """DosageBasicInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._production_line = None
        self._is_intelligence = None
        self._code = None
        self._dosage = None
        self._category = None
        self.discriminator = None

        self.production_line = production_line
        if is_intelligence is not None:
            self.is_intelligence = is_intelligence
        self.code = code
        if dosage is not None:
            self.dosage = dosage
        if category is not None:
            self.category = category

    @property
    def production_line(self):
        """Gets the production_line of this DosageBasicInfo.  # noqa: E501

        该租户下的产线 product line  # noqa: E501

        :return: The production_line of this DosageBasicInfo.  # noqa: E501
        :rtype: str
        """
        return self._production_line

    @production_line.setter
    def production_line(self, production_line):
        """Sets the production_line of this DosageBasicInfo.

        该租户下的产线 product line  # noqa: E501

        :param production_line: The production_line of this DosageBasicInfo.  # noqa: E501
        :type: str
        """

        self._production_line = production_line

    @property
    def is_intelligence(self):
        """Gets the is_intelligence of this DosageBasicInfo.  # noqa: E501

        是否为智能加药，如果是则调用加药算法，如果不是则使用手动加药量发送给下一个接口 if use intelligent dosage  # noqa: E501

        :return: The is_intelligence of this DosageBasicInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_intelligence

    @is_intelligence.setter
    def is_intelligence(self, is_intelligence):
        """Sets the is_intelligence of this DosageBasicInfo.

        是否为智能加药，如果是则调用加药算法，如果不是则使用手动加药量发送给下一个接口 if use intelligent dosage  # noqa: E501

        :param is_intelligence: The is_intelligence of this DosageBasicInfo.  # noqa: E501
        :type: bool
        """

        self._is_intelligence = is_intelligence

    @property
    def code(self):
        """Gets the code of this DosageBasicInfo.  # noqa: E501

        加药量编码 dosing code  # noqa: E501

        :return: The code of this DosageBasicInfo.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this DosageBasicInfo.

        加药量编码 dosing code  # noqa: E501

        :param code: The code of this DosageBasicInfo.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def dosage(self):
        """Gets the dosage of this DosageBasicInfo.  # noqa: E501

        加药量 dosage  # noqa: E501

        :return: The dosage of this DosageBasicInfo.  # noqa: E501
        :rtype: float
        """
        return self._dosage

    @dosage.setter
    def dosage(self, dosage):
        """Sets the dosage of this DosageBasicInfo.

        加药量 dosage  # noqa: E501

        :param dosage: The dosage of this DosageBasicInfo.  # noqa: E501
        :type: float
        """

        self._dosage = dosage

    @property
    def category(self):
        """Gets the category of this DosageBasicInfo.  # noqa: E501

        加药类型 dosing type  # noqa: E501

        :return: The category of this DosageBasicInfo.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DosageBasicInfo.

        加药类型 dosing type  # noqa: E501

        :param category: The category of this DosageBasicInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DosageBasicInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DosageBasicInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class PumpInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'asset_id': 'str',
        'asset_name': 'str',
        'state': 'int',
        'total_minutes': 'float',
        'total_volume': 'float'
    }

    attribute_map = {
        'asset_id': 'assetID',
        'asset_name': 'assetName',
        'state': 'state',
        'total_minutes': 'totalMinutes',
        'total_volume': 'totalVolume'
    }

    def __init__(self, asset_id=None, asset_name=None, state=None, total_minutes=None, total_volume=None, local_vars_configuration=None):  # noqa: E501
        """PumpInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._asset_id = None
        self._asset_name = None
        self._state = None
        self._total_minutes = None
        self._total_volume = None
        self.discriminator = None

        self.asset_id = asset_id
        self.asset_name = asset_name
        if state is not None:
            self.state = state
        if total_minutes is not None:
            self.total_minutes = total_minutes
        if total_volume is not None:
            self.total_volume = total_volume

    @property
    def asset_id(self):
        """Gets the asset_id of this PumpInfo.  # noqa: E501

        泵站id pump id  # noqa: E501

        :return: The asset_id of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this PumpInfo.

        泵站id pump id  # noqa: E501

        :param asset_id: The asset_id of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._asset_id = asset_id

    @property
    def asset_name(self):
        """Gets the asset_name of this PumpInfo.  # noqa: E501

        泵站名称 pump name  # noqa: E501

        :return: The asset_name of this PumpInfo.  # noqa: E501
        :rtype: str
        """
        return self._asset_name

    @asset_name.setter
    def asset_name(self, asset_name):
        """Sets the asset_name of this PumpInfo.

        泵站名称 pump name  # noqa: E501

        :param asset_name: The asset_name of this PumpInfo.  # noqa: E501
        :type: str
        """

        self._asset_name = asset_name

    @property
    def state(self):
        """Gets the state of this PumpInfo.  # noqa: E501

        开关状态(0:关,1:开) switch status (0: off, 1: on)  # noqa: E501

        :return: The state of this PumpInfo.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PumpInfo.

        开关状态(0:关,1:开) switch status (0: off, 1: on)  # noqa: E501

        :param state: The state of this PumpInfo.  # noqa: E501
        :type: int
        """

        self._state = state

    @property
    def total_minutes(self):
        """Gets the total_minutes of this PumpInfo.  # noqa: E501

        总补水时长，以分钟为单位 otal water make-up time (unit:minute)  # noqa: E501

        :return: The total_minutes of this PumpInfo.  # noqa: E501
        :rtype: float
        """
        return self._total_minutes

    @total_minutes.setter
    def total_minutes(self, total_minutes):
        """Sets the total_minutes of this PumpInfo.

        总补水时长，以分钟为单位 otal water make-up time (unit:minute)  # noqa: E501

        :param total_minutes: The total_minutes of this PumpInfo.  # noqa: E501
        :type: float
        """

        self._total_minutes = total_minutes

    @property
    def total_volume(self):
        """Gets the total_volume of this PumpInfo.  # noqa: E501

        总补水量 total make-up water  # noqa: E501

        :return: The total_volume of this PumpInfo.  # noqa: E501
        :rtype: float
        """
        return self._total_volume

    @total_volume.setter
    def total_volume(self, total_volume):
        """Sets the total_volume of this PumpInfo.

        总补水量 total make-up water  # noqa: E501

        :param total_volume: The total_volume of this PumpInfo.  # noqa: E501
        :type: float
        """

        self._total_volume = total_volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PumpInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PumpInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_identity_service.api_client import ApiClient
from dhicn_identity_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UsersMnangerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_app_users_mnanger_query_super_users_post(self, **kwargs):  # noqa: E501
        """查询超级用户 Query super user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_query_super_users_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUsersInput query_users_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QuerySuperUsersOutputPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_query_super_users_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_query_super_users_post_with_http_info(self, **kwargs):  # noqa: E501
        """查询超级用户 Query super user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_query_super_users_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUsersInput query_users_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QuerySuperUsersOutputPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_users_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_query_super_users_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_users_input' in local_var_params:
            body_params = local_var_params['query_users_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/querySuperUsers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QuerySuperUsersOutputPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_query_users_post(self, **kwargs):  # noqa: E501
        """查询用户 Query user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_query_users_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUsersInput query_users_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QueryUsersOutputPage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_query_users_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_query_users_post_with_http_info(self, **kwargs):  # noqa: E501
        """查询用户 Query user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_query_users_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param QueryUsersInput query_users_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QueryUsersOutputPage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'query_users_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_query_users_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_users_input' in local_var_params:
            body_params = local_var_params['query_users_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/queryUsers', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryUsersOutputPage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_reset_password_post(self, **kwargs):  # noqa: E501
        """重置密码 Reset password  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_reset_password_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ResetPasswordInput reset_password_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_reset_password_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_reset_password_post_with_http_info(self, **kwargs):  # noqa: E501
        """重置密码 Reset password  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_reset_password_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ResetPasswordInput reset_password_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'reset_password_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_reset_password_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'reset_password_input' in local_var_params:
            body_params = local_var_params['reset_password_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/resetPassword', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_super_user_post(self, **kwargs):  # noqa: E501
        """添加超级用户 Add super user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_super_user_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddSuperUserInput add_super_user_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_super_user_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_super_user_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加超级用户 Add super user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_super_user_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddSuperUserInput add_super_user_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_super_user_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_super_user_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_super_user_input' in local_var_params:
            body_params = local_var_params['add_super_user_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/superUser', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_super_user_put(self, **kwargs):  # noqa: E501
        """更新超级用户 Update super user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_super_user_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateSuperUserInput update_super_user_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_super_user_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_super_user_put_with_http_info(self, **kwargs):  # noqa: E501
        """更新超级用户 Update super user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_super_user_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateSuperUserInput update_super_user_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_super_user_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_super_user_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_super_user_input' in local_var_params:
            body_params = local_var_params['update_super_user_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/superUser', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_user_oper_post(self, **kwargs):  # noqa: E501
        """启用/停用用户 Enable / Disable users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_oper_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserOperInput user_oper_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_user_oper_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_user_oper_post_with_http_info(self, **kwargs):  # noqa: E501
        """启用/停用用户 Enable / Disable users  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_oper_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserOperInput user_oper_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'user_oper_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_user_oper_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_oper_input' in local_var_params:
            body_params = local_var_params['user_oper_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/userOper', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_user_pers_get(self, **kwargs):  # noqa: E501
        """通过Token获取登录用户-权限信息 Obtain login user permission information through token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_pers_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetUserPersOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_user_pers_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_user_pers_get_with_http_info(self, **kwargs):  # noqa: E501
        """通过Token获取登录用户-权限信息 Obtain login user permission information through token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_pers_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetUserPersOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_user_pers_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/userPers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetUserPersOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_user_post(self, **kwargs):  # noqa: E501
        """添加用户 Add user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserInput add_user_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_user_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_user_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加用户 Add user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddUserInput add_user_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_user_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_user_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_user_input' in local_var_params:
            body_params = local_var_params['add_user_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/user', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_user_put(self, **kwargs):  # noqa: E501
        """更新用户 Update user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateUserInput update_user_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_user_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_users_mnanger_user_put_with_http_info(self, **kwargs):  # noqa: E501
        """更新用户 Update user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateUserInput update_user_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_user_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_user_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_user_input' in local_var_params:
            body_params = local_var_params['update_user_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/user', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_user_user_id_get(self, user_id, **kwargs):  # noqa: E501
        """通过用户id获取用户信息 get user information by userid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_user_id_get(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: QueryUsersWithOrganziationOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_user_user_id_get_with_http_info(user_id, **kwargs)  # noqa: E501

    def api_app_users_mnanger_user_user_id_get_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """通过用户id获取用户信息 get user information by userid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_user_user_id_get_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(QueryUsersWithOrganziationOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'user_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_user_user_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `api_app_users_mnanger_user_user_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/user/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryUsersWithOrganziationOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_users_mnanger_users_delete(self, ids, **kwargs):  # noqa: E501
        """删除用户 Delete user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_users_delete(ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] ids: ID列表 ids (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_users_mnanger_users_delete_with_http_info(ids, **kwargs)  # noqa: E501

    def api_app_users_mnanger_users_delete_with_http_info(self, ids, **kwargs):  # noqa: E501
        """删除用户 Delete user  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_users_mnanger_users_delete_with_http_info(ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] ids: ID列表 ids (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_users_mnanger_users_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'ids' is set
        if self.api_client.client_side_validation and ('ids' not in local_var_params or  # noqa: E501
                                                        local_var_params['ids'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `ids` when calling `api_app_users_mnanger_users_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in local_var_params and local_var_params['ids'] is not None:  # noqa: E501
            query_params.append(('Ids', local_var_params['ids']))  # noqa: E501
            collection_formats['Ids'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/usersMnanger/users', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class DaConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'show_name': 'str',
        'branch_name': 'str',
        'chainage': 'float',
        'variable_type': 'int',
        'component': 'int',
        'file': 'str',
        'file_num': 'int',
        'indicator_id': 'str',
        'template_id': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'show_name': 'showName',
        'branch_name': 'branchName',
        'chainage': 'chainage',
        'variable_type': 'variableType',
        'component': 'component',
        'file': 'file',
        'file_num': 'fileNum',
        'indicator_id': 'indicatorId',
        'template_id': 'templateId',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, show_name=None, branch_name=None, chainage=None, variable_type=None, component=None, file=None, file_num=None, indicator_id=None, template_id=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """DaConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._show_name = None
        self._branch_name = None
        self._chainage = None
        self._variable_type = None
        self._component = None
        self._file = None
        self._file_num = None
        self._indicator_id = None
        self._template_id = None
        self._tenant_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.show_name = show_name
        self.branch_name = branch_name
        if chainage is not None:
            self.chainage = chainage
        if variable_type is not None:
            self.variable_type = variable_type
        if component is not None:
            self.component = component
        self.file = file
        if file_num is not None:
            self.file_num = file_num
        self.indicator_id = indicator_id
        if template_id is not None:
            self.template_id = template_id
        self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this DaConfigOutput.  # noqa: E501


        :return: The id of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DaConfigOutput.


        :param id: The id of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def show_name(self):
        """Gets the show_name of this DaConfigOutput.  # noqa: E501

        校正点显示名称 DA point name  # noqa: E501

        :return: The show_name of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this DaConfigOutput.

        校正点显示名称 DA point name  # noqa: E501

        :param show_name: The show_name of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def branch_name(self):
        """Gets the branch_name of this DaConfigOutput.  # noqa: E501

        河道名 branch name  # noqa: E501

        :return: The branch_name of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._branch_name

    @branch_name.setter
    def branch_name(self, branch_name):
        """Sets the branch_name of this DaConfigOutput.

        河道名 branch name  # noqa: E501

        :param branch_name: The branch_name of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._branch_name = branch_name

    @property
    def chainage(self):
        """Gets the chainage of this DaConfigOutput.  # noqa: E501

        里程数 chainage  # noqa: E501

        :return: The chainage of this DaConfigOutput.  # noqa: E501
        :rtype: float
        """
        return self._chainage

    @chainage.setter
    def chainage(self, chainage):
        """Sets the chainage of this DaConfigOutput.

        里程数 chainage  # noqa: E501

        :param chainage: The chainage of this DaConfigOutput.  # noqa: E501
        :type: float
        """

        self._chainage = chainage

    @property
    def variable_type(self):
        """Gets the variable_type of this DaConfigOutput.  # noqa: E501

        0-WaterLevel(water level) 1-Discharge(discharge) 2-Concentration(concentration)   # noqa: E501

        :return: The variable_type of this DaConfigOutput.  # noqa: E501
        :rtype: int
        """
        return self._variable_type

    @variable_type.setter
    def variable_type(self, variable_type):
        """Sets the variable_type of this DaConfigOutput.

        0-WaterLevel(water level) 1-Discharge(discharge) 2-Concentration(concentration)   # noqa: E501

        :param variable_type: The variable_type of this DaConfigOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and variable_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `variable_type` ({0}), must be one of {1}"  # noqa: E501
                .format(variable_type, allowed_values)
            )

        self._variable_type = variable_type

    @property
    def component(self):
        """Gets the component of this DaConfigOutput.  # noqa: E501

        水质项序号 component number  # noqa: E501

        :return: The component of this DaConfigOutput.  # noqa: E501
        :rtype: int
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this DaConfigOutput.

        水质项序号 component number  # noqa: E501

        :param component: The component of this DaConfigOutput.  # noqa: E501
        :type: int
        """

        self._component = component

    @property
    def file(self):
        """Gets the file of this DaConfigOutput.  # noqa: E501

        dfs0文件相对路径 dfs0 file path  # noqa: E501

        :return: The file of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this DaConfigOutput.

        dfs0文件相对路径 dfs0 file path  # noqa: E501

        :param file: The file of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._file = file

    @property
    def file_num(self):
        """Gets the file_num of this DaConfigOutput.  # noqa: E501

        dfs0文件中项的序号 dfs0 data item number  # noqa: E501

        :return: The file_num of this DaConfigOutput.  # noqa: E501
        :rtype: int
        """
        return self._file_num

    @file_num.setter
    def file_num(self, file_num):
        """Sets the file_num of this DaConfigOutput.

        dfs0文件中项的序号 dfs0 data item number  # noqa: E501

        :param file_num: The file_num of this DaConfigOutput.  # noqa: E501
        :type: int
        """

        self._file_num = file_num

    @property
    def indicator_id(self):
        """Gets the indicator_id of this DaConfigOutput.  # noqa: E501

        指标Id device indicator id  # noqa: E501

        :return: The indicator_id of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._indicator_id

    @indicator_id.setter
    def indicator_id(self, indicator_id):
        """Sets the indicator_id of this DaConfigOutput.

        指标Id device indicator id  # noqa: E501

        :param indicator_id: The indicator_id of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._indicator_id = indicator_id

    @property
    def template_id(self):
        """Gets the template_id of this DaConfigOutput.  # noqa: E501

        模板方案Id template scenario id  # noqa: E501

        :return: The template_id of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this DaConfigOutput.

        模板方案Id template scenario id  # noqa: E501

        :param template_id: The template_id of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DaConfigOutput.  # noqa: E501

        租户Id tenant id  # noqa: E501

        :return: The tenant_id of this DaConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DaConfigOutput.

        租户Id tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this DaConfigOutput.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DaConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DaConfigOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class ControlDeviceTsDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'create_time': 'datetime',
        'device_code': 'str',
        'is_intelligence': 'bool',
        'value': 'float',
        'indicator': 'str'
    }

    attribute_map = {
        'create_time': 'createTime',
        'device_code': 'deviceCode',
        'is_intelligence': 'isIntelligence',
        'value': 'value',
        'indicator': 'indicator'
    }

    def __init__(self, create_time=None, device_code=None, is_intelligence=None, value=None, indicator=None, local_vars_configuration=None):  # noqa: E501
        """ControlDeviceTsDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._create_time = None
        self._device_code = None
        self._is_intelligence = None
        self._value = None
        self._indicator = None
        self.discriminator = None

        if create_time is not None:
            self.create_time = create_time
        self.device_code = device_code
        if is_intelligence is not None:
            self.is_intelligence = is_intelligence
        if value is not None:
            self.value = value
        self.indicator = indicator

    @property
    def create_time(self):
        """Gets the create_time of this ControlDeviceTsDetails.  # noqa: E501


        :return: The create_time of this ControlDeviceTsDetails.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ControlDeviceTsDetails.


        :param create_time: The create_time of this ControlDeviceTsDetails.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def device_code(self):
        """Gets the device_code of this ControlDeviceTsDetails.  # noqa: E501


        :return: The device_code of this ControlDeviceTsDetails.  # noqa: E501
        :rtype: str
        """
        return self._device_code

    @device_code.setter
    def device_code(self, device_code):
        """Sets the device_code of this ControlDeviceTsDetails.


        :param device_code: The device_code of this ControlDeviceTsDetails.  # noqa: E501
        :type: str
        """

        self._device_code = device_code

    @property
    def is_intelligence(self):
        """Gets the is_intelligence of this ControlDeviceTsDetails.  # noqa: E501


        :return: The is_intelligence of this ControlDeviceTsDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_intelligence

    @is_intelligence.setter
    def is_intelligence(self, is_intelligence):
        """Sets the is_intelligence of this ControlDeviceTsDetails.


        :param is_intelligence: The is_intelligence of this ControlDeviceTsDetails.  # noqa: E501
        :type: bool
        """

        self._is_intelligence = is_intelligence

    @property
    def value(self):
        """Gets the value of this ControlDeviceTsDetails.  # noqa: E501


        :return: The value of this ControlDeviceTsDetails.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ControlDeviceTsDetails.


        :param value: The value of this ControlDeviceTsDetails.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def indicator(self):
        """Gets the indicator of this ControlDeviceTsDetails.  # noqa: E501


        :return: The indicator of this ControlDeviceTsDetails.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this ControlDeviceTsDetails.


        :param indicator: The indicator of this ControlDeviceTsDetails.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ControlDeviceTsDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ControlDeviceTsDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class DosingStatisticDailysInOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'statistic_code': 'str',
        'time': 'datetime',
        'value': 'float',
        'cost_value': 'float',
        'cal_value': 'float',
        'category': 'int',
        'product_line': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'statistic_code': 'statisticCode',
        'time': 'time',
        'value': 'value',
        'cost_value': 'costValue',
        'cal_value': 'calValue',
        'category': 'category',
        'product_line': 'productLine',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, statistic_code=None, time=None, value=None, cost_value=None, cal_value=None, category=None, product_line=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """DosingStatisticDailysInOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._statistic_code = None
        self._time = None
        self._value = None
        self._cost_value = None
        self._cal_value = None
        self._category = None
        self._product_line = None
        self._tenant_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.statistic_code = statistic_code
        if time is not None:
            self.time = time
        if value is not None:
            self.value = value
        if cost_value is not None:
            self.cost_value = cost_value
        if cal_value is not None:
            self.cal_value = cal_value
        if category is not None:
            self.category = category
        self.product_line = product_line
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this DosingStatisticDailysInOut.  # noqa: E501

        统计数据ID data id  # noqa: E501

        :return: The id of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DosingStatisticDailysInOut.

        统计数据ID data id  # noqa: E501

        :param id: The id of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def statistic_code(self):
        """Gets the statistic_code of this DosingStatisticDailysInOut.  # noqa: E501

        统计编码 statistic code  # noqa: E501

        :return: The statistic_code of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._statistic_code

    @statistic_code.setter
    def statistic_code(self, statistic_code):
        """Sets the statistic_code of this DosingStatisticDailysInOut.

        统计编码 statistic code  # noqa: E501

        :param statistic_code: The statistic_code of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._statistic_code = statistic_code

    @property
    def time(self):
        """Gets the time of this DosingStatisticDailysInOut.  # noqa: E501

        时间 time  # noqa: E501

        :return: The time of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this DosingStatisticDailysInOut.

        时间 time  # noqa: E501

        :param time: The time of this DosingStatisticDailysInOut.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def value(self):
        """Gets the value of this DosingStatisticDailysInOut.  # noqa: E501

        实际投加值 actual dosage  # noqa: E501

        :return: The value of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this DosingStatisticDailysInOut.

        实际投加值 actual dosage  # noqa: E501

        :param value: The value of this DosingStatisticDailysInOut.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def cost_value(self):
        """Gets the cost_value of this DosingStatisticDailysInOut.  # noqa: E501

        药耗值 actual dosage cost  # noqa: E501

        :return: The cost_value of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: float
        """
        return self._cost_value

    @cost_value.setter
    def cost_value(self, cost_value):
        """Sets the cost_value of this DosingStatisticDailysInOut.

        药耗值 actual dosage cost  # noqa: E501

        :param cost_value: The cost_value of this DosingStatisticDailysInOut.  # noqa: E501
        :type: float
        """

        self._cost_value = cost_value

    @property
    def cal_value(self):
        """Gets the cal_value of this DosingStatisticDailysInOut.  # noqa: E501

        计算投加值 calculated dosage  # noqa: E501

        :return: The cal_value of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: float
        """
        return self._cal_value

    @cal_value.setter
    def cal_value(self, cal_value):
        """Sets the cal_value of this DosingStatisticDailysInOut.

        计算投加值 calculated dosage  # noqa: E501

        :param cal_value: The cal_value of this DosingStatisticDailysInOut.  # noqa: E501
        :type: float
        """

        self._cal_value = cal_value

    @property
    def category(self):
        """Gets the category of this DosingStatisticDailysInOut.  # noqa: E501

        药剂投加类别  # noqa: E501

        :return: The category of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DosingStatisticDailysInOut.

        药剂投加类别  # noqa: E501

        :param category: The category of this DosingStatisticDailysInOut.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    @property
    def product_line(self):
        """Gets the product_line of this DosingStatisticDailysInOut.  # noqa: E501

        生产线代码 product line code  # noqa: E501

        :return: The product_line of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this DosingStatisticDailysInOut.

        生产线代码 product line code  # noqa: E501

        :param product_line: The product_line of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DosingStatisticDailysInOut.  # noqa: E501

        租户ID tenant id  # noqa: E501

        :return: The tenant_id of this DosingStatisticDailysInOut.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DosingStatisticDailysInOut.

        租户ID tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this DosingStatisticDailysInOut.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DosingStatisticDailysInOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DosingStatisticDailysInOut):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    message-center-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_message_service.configuration import Configuration


class UserMsgOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'sender_user_id': 'str',
        'sender_organ_name': 'str',
        'sender_real_name': 'str',
        'receiver_user_id': 'str',
        'receiver_organ_name': 'str',
        'receiver_real_name': 'str',
        'level': 'int',
        'msg_type': 'str',
        'message': 'UserMessageObject',
        'is_read': 'bool',
        'is_mark': 'bool',
        'creation_time': 'datetime',
        'last_modification_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'sender_user_id': 'senderUserId',
        'sender_organ_name': 'senderOrganName',
        'sender_real_name': 'senderRealName',
        'receiver_user_id': 'receiverUserId',
        'receiver_organ_name': 'receiverOrganName',
        'receiver_real_name': 'receiverRealName',
        'level': 'level',
        'msg_type': 'msgType',
        'message': 'message',
        'is_read': 'isRead',
        'is_mark': 'isMark',
        'creation_time': 'creationTime',
        'last_modification_time': 'lastModificationTime'
    }

    def __init__(self, id=None, sender_user_id=None, sender_organ_name=None, sender_real_name=None, receiver_user_id=None, receiver_organ_name=None, receiver_real_name=None, level=None, msg_type=None, message=None, is_read=None, is_mark=None, creation_time=None, last_modification_time=None, local_vars_configuration=None):  # noqa: E501
        """UserMsgOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._sender_user_id = None
        self._sender_organ_name = None
        self._sender_real_name = None
        self._receiver_user_id = None
        self._receiver_organ_name = None
        self._receiver_real_name = None
        self._level = None
        self._msg_type = None
        self._message = None
        self._is_read = None
        self._is_mark = None
        self._creation_time = None
        self._last_modification_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if sender_user_id is not None:
            self.sender_user_id = sender_user_id
        self.sender_organ_name = sender_organ_name
        self.sender_real_name = sender_real_name
        if receiver_user_id is not None:
            self.receiver_user_id = receiver_user_id
        self.receiver_organ_name = receiver_organ_name
        self.receiver_real_name = receiver_real_name
        if level is not None:
            self.level = level
        self.msg_type = msg_type
        if message is not None:
            self.message = message
        if is_read is not None:
            self.is_read = is_read
        if is_mark is not None:
            self.is_mark = is_mark
        if creation_time is not None:
            self.creation_time = creation_time
        self.last_modification_time = last_modification_time

    @property
    def id(self):
        """Gets the id of this UserMsgOutput.  # noqa: E501


        :return: The id of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserMsgOutput.


        :param id: The id of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def sender_user_id(self):
        """Gets the sender_user_id of this UserMsgOutput.  # noqa: E501

        发送人ID  # noqa: E501

        :return: The sender_user_id of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._sender_user_id

    @sender_user_id.setter
    def sender_user_id(self, sender_user_id):
        """Sets the sender_user_id of this UserMsgOutput.

        发送人ID  # noqa: E501

        :param sender_user_id: The sender_user_id of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._sender_user_id = sender_user_id

    @property
    def sender_organ_name(self):
        """Gets the sender_organ_name of this UserMsgOutput.  # noqa: E501

        发送人组织名称  # noqa: E501

        :return: The sender_organ_name of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._sender_organ_name

    @sender_organ_name.setter
    def sender_organ_name(self, sender_organ_name):
        """Sets the sender_organ_name of this UserMsgOutput.

        发送人组织名称  # noqa: E501

        :param sender_organ_name: The sender_organ_name of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._sender_organ_name = sender_organ_name

    @property
    def sender_real_name(self):
        """Gets the sender_real_name of this UserMsgOutput.  # noqa: E501

        发送人真实姓名  # noqa: E501

        :return: The sender_real_name of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._sender_real_name

    @sender_real_name.setter
    def sender_real_name(self, sender_real_name):
        """Sets the sender_real_name of this UserMsgOutput.

        发送人真实姓名  # noqa: E501

        :param sender_real_name: The sender_real_name of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._sender_real_name = sender_real_name

    @property
    def receiver_user_id(self):
        """Gets the receiver_user_id of this UserMsgOutput.  # noqa: E501

        接收人ID  # noqa: E501

        :return: The receiver_user_id of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._receiver_user_id

    @receiver_user_id.setter
    def receiver_user_id(self, receiver_user_id):
        """Sets the receiver_user_id of this UserMsgOutput.

        接收人ID  # noqa: E501

        :param receiver_user_id: The receiver_user_id of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._receiver_user_id = receiver_user_id

    @property
    def receiver_organ_name(self):
        """Gets the receiver_organ_name of this UserMsgOutput.  # noqa: E501

        接收人组织名称  # noqa: E501

        :return: The receiver_organ_name of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._receiver_organ_name

    @receiver_organ_name.setter
    def receiver_organ_name(self, receiver_organ_name):
        """Sets the receiver_organ_name of this UserMsgOutput.

        接收人组织名称  # noqa: E501

        :param receiver_organ_name: The receiver_organ_name of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._receiver_organ_name = receiver_organ_name

    @property
    def receiver_real_name(self):
        """Gets the receiver_real_name of this UserMsgOutput.  # noqa: E501

        接收人真实姓名  # noqa: E501

        :return: The receiver_real_name of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._receiver_real_name

    @receiver_real_name.setter
    def receiver_real_name(self, receiver_real_name):
        """Sets the receiver_real_name of this UserMsgOutput.

        接收人真实姓名  # noqa: E501

        :param receiver_real_name: The receiver_real_name of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._receiver_real_name = receiver_real_name

    @property
    def level(self):
        """Gets the level of this UserMsgOutput.  # noqa: E501

        消息等级,默认为0.  针对套子湾项目约定:1:重要;2:紧急;3:十万火急.  # noqa: E501

        :return: The level of this UserMsgOutput.  # noqa: E501
        :rtype: int
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this UserMsgOutput.

        消息等级,默认为0.  针对套子湾项目约定:1:重要;2:紧急;3:十万火急.  # noqa: E501

        :param level: The level of this UserMsgOutput.  # noqa: E501
        :type: int
        """

        self._level = level

    @property
    def msg_type(self):
        """Gets the msg_type of this UserMsgOutput.  # noqa: E501

        消息类型  # noqa: E501

        :return: The msg_type of this UserMsgOutput.  # noqa: E501
        :rtype: str
        """
        return self._msg_type

    @msg_type.setter
    def msg_type(self, msg_type):
        """Sets the msg_type of this UserMsgOutput.

        消息类型  # noqa: E501

        :param msg_type: The msg_type of this UserMsgOutput.  # noqa: E501
        :type: str
        """

        self._msg_type = msg_type

    @property
    def message(self):
        """Gets the message of this UserMsgOutput.  # noqa: E501


        :return: The message of this UserMsgOutput.  # noqa: E501
        :rtype: UserMessageObject
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this UserMsgOutput.


        :param message: The message of this UserMsgOutput.  # noqa: E501
        :type: UserMessageObject
        """

        self._message = message

    @property
    def is_read(self):
        """Gets the is_read of this UserMsgOutput.  # noqa: E501

        是否已读  # noqa: E501

        :return: The is_read of this UserMsgOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_read

    @is_read.setter
    def is_read(self, is_read):
        """Sets the is_read of this UserMsgOutput.

        是否已读  # noqa: E501

        :param is_read: The is_read of this UserMsgOutput.  # noqa: E501
        :type: bool
        """

        self._is_read = is_read

    @property
    def is_mark(self):
        """Gets the is_mark of this UserMsgOutput.  # noqa: E501

        是否标记  # noqa: E501

        :return: The is_mark of this UserMsgOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_mark

    @is_mark.setter
    def is_mark(self, is_mark):
        """Sets the is_mark of this UserMsgOutput.

        是否标记  # noqa: E501

        :param is_mark: The is_mark of this UserMsgOutput.  # noqa: E501
        :type: bool
        """

        self._is_mark = is_mark

    @property
    def creation_time(self):
        """Gets the creation_time of this UserMsgOutput.  # noqa: E501

        创建时间  # noqa: E501

        :return: The creation_time of this UserMsgOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this UserMsgOutput.

        创建时间  # noqa: E501

        :param creation_time: The creation_time of this UserMsgOutput.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def last_modification_time(self):
        """Gets the last_modification_time of this UserMsgOutput.  # noqa: E501


        :return: The last_modification_time of this UserMsgOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modification_time

    @last_modification_time.setter
    def last_modification_time(self, last_modification_time):
        """Sets the last_modification_time of this UserMsgOutput.


        :param last_modification_time: The last_modification_time of this UserMsgOutput.  # noqa: E501
        :type: datetime
        """

        self._last_modification_time = last_modification_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserMsgOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserMsgOutput):
            return True

        return self.to_dict() != other.to_dict()
